==> estateplat-common-1.2.4-20220901.064142-1089-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXxcxjl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/10
 * @description 不动产信息查询记录表，主要记录每次不动产信息查询操作，包括查询条件、时间、操作人、IP地址等
 */
@Table(name ="bdc_xxcxjl")
public class BdcXxcxjl implements Serializable{
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主键
     */
    @Id
    private String jlid ;

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 查询编号
     */
    private String cxbh;

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 查询人名称
     */
    private String cxrmc;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 查询人证件号
     */
    private String cxrzjh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 查询坐落
     */
    private String  cxzl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 操作人名称
     */
    private String czrmc;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 操作时间
     */
    private Date czsj;

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 操作IP地址
     */
    private String czip;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 查询类别
     */
    private String cxlb;

    /**
     * @description 操作类别
     */
    private String czlb;

    /**
     * @description 查询产权证号
     */
    private String cxcqzh;

    /**
     * @description 查询目的
     */
    private String cxmd;

    /**
     * @description 查询机器编号
     */
    private String cxjqbh;

    /**
     * @description 查询人照片路径
     */
    private String cxrzplj;
    /**
     * @description 原查询记录id（记录打印操作对应的查询记录）
     */
    private String ycxjlid;
    /**
     * @description 授权材料路径
     */
    private String sqcl;


    public String getCxmd() {
        return cxmd;
    }

    public void setCxmd(String cxmd) {
        this.cxmd = cxmd;
    }

    public String getJlid() {
        return jlid;
    }

    public void setJlid(String jlid) {
        this.jlid = jlid;
    }

    public String getCxbh() {
        return cxbh;
    }

    public void setCxbh(String cxbh) {
        this.cxbh = cxbh;
    }

    public String getCxrmc() {
        return cxrmc;
    }

    public void setCxrmc(String cxrmc) {
        this.cxrmc = cxrmc;
    }

    public String getCxrzjh() {
        return cxrzjh;
    }

    public void setCxrzjh(String cxrzjh) {
        this.cxrzjh = cxrzjh;
    }

    public String getCxzl() {
        return cxzl;
    }

    public void setCxzl(String cxzl) {
        this.cxzl = cxzl;
    }

    public String getCzrmc() {
        return czrmc;
    }

    public void setCzrmc(String czrmc) {
        this.czrmc = czrmc;
    }

    public Date getCzsj() {
        return czsj;
    }

    public void setCzsj(Date czsj) {
        this.czsj = czsj;
    }

    public String getCxlb() {
        return cxlb;
    }

    public void setCxlb(String cxlb) {
        this.cxlb = cxlb;
    }

    public String getCzip() {
        return czip;
    }

    public void setCzip(String czip) {
        this.czip = czip;
    }

    public String getCzlb() {
        return czlb;
    }

    public void setCzlb(String czlb) {
        this.czlb = czlb;
    }

    public String getCxcqzh() {
        return cxcqzh;
    }

    public void setCxcqzh(String cxcqzh) {
        this.cxcqzh = cxcqzh;
    }

    public String getCxjqbh() {
        return cxjqbh;
    }

    public void setCxjqbh(String cxjqbh) {
        this.cxjqbh = cxjqbh;
    }

    public String getCxrzplj() {
        return cxrzplj;
    }

    public void setCxrzplj(String cxrzplj) {
        this.cxrzplj = cxrzplj;
    }

    public String getYcxjlid() {
        return ycxjlid;
    }

    public void setYcxjlid(String ycxjlid) {
        this.ycxjlid = ycxjlid;
    }

    public String getSqcl() {
        return sqcl;
    }

    public void setSqcl(String sqcl) {
        this.sqcl = sqcl;
    }
}

==> estateplat-common-1.2.4-20230216.033320-1144-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXxcxjl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/10
 * @description 不动产信息查询记录表，主要记录每次不动产信息查询操作，包括查询条件、时间、操作人、IP地址等
 */
@Table(name ="bdc_xxcxjl")
public class BdcXxcxjl implements Serializable{
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 主键
     */
    @Id
    private String jlid ;

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 查询编号
     */
    private String cxbh;

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 查询人名称
     */
    private String cxrmc;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 查询人证件号
     */
    private String cxrzjh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 查询坐落
     */
    private String  cxzl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 操作人名称
     */
    private String czrmc;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 操作时间
     */
    private Date czsj;

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/3
     * @description 操作IP地址
     */
    private String czip;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 查询类别
     */
    private String cxlb;

    /**
     * @description 操作类别
     */
    private String czlb;

    /**
     * @description 查询产权证号
     */
    private String cxcqzh;

    /**
     * @description 查询目的
     */
    private String cxmd;

    /**
     * @description 查询机器编号
     */
    private String cxjqbh;

    /**
     * @description 查询人照片路径
     */
    private String cxrzplj;
    /**
     * @description 原查询记录id（记录打印操作对应的查询记录）
     */
    private String ycxjlid;
    /**
     * @description 授权材料路径
     */
    private String sqcl;
    /**
     * @description 查询原因
     */
    private String cxyy;


    public String getCxmd() {
        return cxmd;
    }

    public void setCxmd(String cxmd) {
        this.cxmd = cxmd;
    }

    public String getJlid() {
        return jlid;
    }

    public void setJlid(String jlid) {
        this.jlid = jlid;
    }

    public String getCxbh() {
        return cxbh;
    }

    public void setCxbh(String cxbh) {
        this.cxbh = cxbh;
    }

    public String getCxrmc() {
        return cxrmc;
    }

    public void setCxrmc(String cxrmc) {
        this.cxrmc = cxrmc;
    }

    public String getCxrzjh() {
        return cxrzjh;
    }

    public void setCxrzjh(String cxrzjh) {
        this.cxrzjh = cxrzjh;
    }

    public String getCxzl() {
        return cxzl;
    }

    public void setCxzl(String cxzl) {
        this.cxzl = cxzl;
    }

    public String getCzrmc() {
        return czrmc;
    }

    public void setCzrmc(String czrmc) {
        this.czrmc = czrmc;
    }

    public Date getCzsj() {
        return czsj;
    }

    public void setCzsj(Date czsj) {
        this.czsj = czsj;
    }

    public String getCxlb() {
        return cxlb;
    }

    public void setCxlb(String cxlb) {
        this.cxlb = cxlb;
    }

    public String getCzip() {
        return czip;
    }

    public void setCzip(String czip) {
        this.czip = czip;
    }

    public String getCzlb() {
        return czlb;
    }

    public void setCzlb(String czlb) {
        this.czlb = czlb;
    }

    public String getCxcqzh() {
        return cxcqzh;
    }

    public void setCxcqzh(String cxcqzh) {
        this.cxcqzh = cxcqzh;
    }

    public String getCxjqbh() {
        return cxjqbh;
    }

    public void setCxjqbh(String cxjqbh) {
        this.cxjqbh = cxjqbh;
    }

    public String getCxrzplj() {
        return cxrzplj;
    }

    public void setCxrzplj(String cxrzplj) {
        this.cxrzplj = cxrzplj;
    }

    public String getYcxjlid() {
        return ycxjlid;
    }

    public void setYcxjlid(String ycxjlid) {
        this.ycxjlid = ycxjlid;
    }

    public String getSqcl() {
        return sqcl;
    }

    public void setSqcl(String sqcl) {
        this.sqcl = sqcl;
    }

    public String getCxyy() {
        return cxyy;
    }

    public void setCxyy(String cxyy) {
        this.cxyy = cxyy;
    }
}
